// Format: '@exp:2025-06-15' or '@exp:+7d' (or '@expires')
const EXPIRATION_DATE_REGEX = /^(@(?:exp|expires):(?:(?:\d{4}-\d{2}-\d{2})|(?:\+\d+[dwmy])))\s*(.*)/

export const formatDateLong = (dateString: string | Date): string => {
	if (!dateString) {
		return ""
	}

	const d = new Date(dateString)
	return d.toLocaleDateString(undefined, {
		weekday: "short",
		year: "2-digit",
		month: "short",
		day: "numeric",
		hour: "numeric",
		minute: "numeric"
	})
}

export const formatDateShort = (dateString: string | Date): string => {
	if (!dateString) {
		return ""
	}

	const d = new Date(dateString)
	return d.toLocaleDateString(undefined, {
		weekday: "short",
		year: "2-digit",
		month: "short"
	})
}

export const parseExpirationPrefix = (title: string): [string, string] => {
	const match = title.match(EXPIRATION_DATE_REGEX)

	if (match && match[1]) {
		// console.log(`[UTIL] Extracted expiration prefix: '${match[1]}'`)
		// return [clean title, expiration prefix]
		return [match[2], match[1]]
	}

	return [title, ""]
}

export const formatTitleWithHighlight = (title: string): string => {
	const [cleanTitle, expirationPrefix] = parseExpirationPrefix(title)
	if (expirationPrefix === "") {
		return title
	}

	return `<span class="note-title-exp-highlight">${expirationPrefix}</span> ${cleanTitle}`
}
